@@ -1,9 +1,9 @@
 function populateOffsets(columns) {
     let rows = Math.ceil(fileLen / columns);
     let elements = "";
-    var offset = 0;
+    let offset = 0;
 
-    for (var i = 0; i < rows; ++i) {
+    for (let i = 0; i < rows; ++i) {
         elements += offset.toString(16) + "</br>\n";
         offset += columns;
     }
