@@ -319,10 +319,10 @@ fn generate_strtab_data(o: &mut String, section: &[u8]) {
 
             let maybe = std::str::from_utf8(&section[curr_start..=end]);
 
-            if maybe.is_ok() && section[curr_start] != 0 {
-                let string = maybe.unwrap();
-
-                w!(o, 9, "{}", string);
+            if let Ok(string) = maybe {
+                if section[curr_start] != 0 {
+                    w!(o, 9, "{}", string);
+                }
             }
 
             curr_start = i + 1;
@@ -345,20 +345,12 @@ fn generate_section_info_table(o: &mut String, elf: &ParsedElf, shdr: &ParsedShd
     }
 }
 
-// this is ugly
 fn has_segment_detail(ptype: u32) -> bool {
-    match ptype {
-        PT_INTERP => true,
-        PT_NOTE => true,
-        _ => false,
-    }
+    matches!(ptype, PT_INTERP | PT_NOTE)
 }
 
 fn has_section_detail(ptype: u32) -> bool {
-    match ptype {
-        SHT_STRTAB => true,
-        _ => false,
-    }
+    matches!(ptype, SHT_STRTAB)
 }
 
 fn generate_segment_info_tables(o: &mut String, elf: &ParsedElf) {
@@ -372,7 +364,7 @@ fn generate_segment_info_tables(o: &mut String, elf: &ParsedElf) {
 
         if has_segment_detail(phdr.ptype) {
             w!(o, 6, "<tr><td><br></td></tr>");
-            generate_segment_info_table(o, elf, &phdr);
+            generate_segment_info_table(o, elf, phdr);
         }
 
         w!(o, 5, "</table>");
@@ -389,7 +381,7 @@ fn generate_section_info_tables(o: &mut String, elf: &ParsedElf) {
 
         if has_section_detail(shdr.shtype) {
             w!(o, 6, "<tr><td><br></td></tr>");
-            generate_section_info_table(o, elf, &shdr);
+            generate_section_info_table(o, elf, shdr);
         }
 
         w!(o, 5, "</table>");
@@ -565,72 +557,16 @@ fn generate_dump_for_byte(idx: usize, dump: &mut String, elf: &ParsedElf) {
         dump.push_str("</span>");
     }
 
-    dump.push_str(if (idx + 1) % DEFAULT_COLUMNS == 0 { "\n" } else { " " });
-}
-
-// assumes balance == 1
-fn skip_bytes(idx: usize, len: usize, elf: &ParsedElf) -> Option<usize> {
-    if !(elf.ranges.data[idx].len() == 1 && elf.ranges.data[idx][0].skippable()) {
-        return None;
+    if idx != elf.contents.len() - 1 {
+        dump.push_str(if (idx + 1) % DEFAULT_COLUMNS == 0 { "\n" } else { " " });
     }
-
-    let mut new_idx = idx + 1;
-
-    while new_idx < len {
-        match elf.ranges.data[new_idx].len() {
-            0 => {
-                new_idx += 1;
-            }
-
-            1 => {
-                if elf.ranges.data[new_idx][0] == RangeType::End {
-                    return Some(new_idx);
-                }
-
-                return None;
-            }
-
-            _ => {
-                return None;
-            }
-        }
-    }
-
-    None
 }
 
 fn generate_file_dump(elf: &ParsedElf) -> String {
     let mut dump = String::new();
-    let mut i = 0;
-    let len = elf.contents.len();
-    let mut balance: i64 = 0;
 
-    while i < len {
-        // we are iterating twice for one byte, which is not very smart
-        for r in &elf.ranges.data[i] {
-            if *r == RangeType::End {
-                balance -= 1;
-            } else {
-                balance += 1;
-            }
-        }
-
-        // account for one potential skippable range which would already start (incr. balance by 1)
-        // disable while working on offsets
-        if false && balance == 1 {
-            if let Some(new_idx) = skip_bytes(i, len, elf) {
-                dump +=
-                    format!("<span {}>..</span>", elf.ranges.data[i][0].span_attributes()).as_str();
-
-                dump += if (i + 1) % DEFAULT_COLUMNS == 0 { "\n" } else { " " };
-
-                i = new_idx;
-                continue;
-            }
-        }
-
-        generate_dump_for_byte(i, &mut dump, elf);
-        i += 1;
+    for idx in 0..elf.contents.len() {
+        generate_dump_for_byte(idx, &mut dump, elf);
     }
 
     dump
@@ -681,7 +617,7 @@ fn generate_body(o: &mut String, elf: &ParsedElf) {
 
     wnonl!(o, 2, "<div id='bytes'>");
     wnonl!(o, 0, "{}", generate_file_dump(elf));
-    w!(o, 2, "</div>");
+    w!(o, 0, "</div>");
 
     wnonl!(o, 2, "<div id='ascii'>");
     generate_ascii_dump(o, elf);
